@@ -374,6 +374,11 @@ class Client(object):
                 self.options.headless = headless
                 self.get_firefox_profile_dir()
                 self.driver = webdriver.Firefox(options=self.options, firefox_profile=self.data_path, executable_path=self.gecko)
+                # FIX TO ENSURE EXTENSION LOADS.
+                self.driver.get(self.coilurl)  # OPEN URL
+                time.sleep(3)
+                self.driver.install_addon(self.coil_ext_id_path)
+                # END FIX TO ENSURE EXTENSION LOADS.
                 self.driver.get(self.coilurl)  # OPEN URL
                 self.schedule()
 
